@@ -36,7 +36,7 @@ impl Message for TestMessage {
 // to annotate the implementation with the `async_trait` macro (a
 // re-export of the async-trait crate).
 #[async_trait]
-impl Handler<TestMessage, TestEvent> for TestActor {
+impl Handler<TestEvent, TestMessage> for TestActor {
     async fn handle(&mut self, msg: TestMessage, ctx: &mut ActorContext<TestEvent>) -> String {
         log::debug!("received message! {:?}", &msg);
         self.counter += 1;
@@ -78,7 +78,7 @@ async fn simple_message() {
     });
 
     // Wait a little for the actor to start up
-    tokio::time::sleep(tokio::time::Duration::from_millis(100)).await;
+    tokio::time::sleep(tokio::time::Duration::from_millis(5)).await;
 
     // Send the actor the message through an `ask` from which we will get a response
     let response = actor_ref.ask(msg).await.unwrap();
